@@ -1,8 +1,16 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (c) Microsoft Corporation and Dapr Contributors.
-Licensed under the MIT License.
+Copyright 2021 The Dapr Authors
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+    http://www.apache.org/licenses/LICENSE-2.0
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
 """
 
 import grpc
@@ -42,6 +50,10 @@ class App:
     def __del__(self):
         self.stop()
 
+    def add_external_service(self, servicer_callback, external_servicer):
+        """Adds an external gRPC service to the same server"""
+        servicer_callback(external_servicer, self._server)
+
     def run(self, app_port: Optional[int]) -> None:
         """Starts app gRPC server and waits until :class:`App`.stop() is called."""
         if app_port is None:
@@ -96,7 +108,7 @@ class App:
         return decorator
 
     def subscribe(self, pubsub_name: str, topic: str, metadata: Optional[Dict[str, str]] = {},
-                  rule: Optional[Rule] = None):
+                  rule: Optional[Rule] = None, disable_topic_validation: Optional[bool] = False):
         """A decorator that is used to register the subscribing topic method.
 
         The below example registers 'topic' subscription topic and pass custom
@@ -115,7 +127,8 @@ class App:
                 during initialization
         """
         def decorator(func):
-            self._servicer.register_topic(pubsub_name, topic, func, metadata, rule)
+            self._servicer.register_topic(pubsub_name, topic, func, metadata, rule,
+                                          disable_topic_validation)
         return decorator
 
     def binding(self, name: str):
